@@ -1,4 +1,7 @@
+from gettext import gettext as _
+
 from gi.repository import Gtk
+
 from lutris.gui.widgets.download_progress import DownloadProgressBox
 
 
@@ -6,10 +9,10 @@ class DownloadDialog(Gtk.Dialog):
     """Dialog showing a download in progress."""
 
     def __init__(self, url=None, dest=None, title=None, label=None, downloader=None):
-        Gtk.Dialog.__init__(self, title or "Downloading file")
+        Gtk.Dialog.__init__(self, title or _("Downloading file"))
         self.set_size_request(485, 104)
         self.set_border_width(12)
-        params = {"url": url, "dest": dest, "title": label or "Downloading %s" % url}
+        params = {"url": url, "dest": dest, "title": label or _("Downloading %s") % url}
         self.download_box = DownloadProgressBox(params, downloader=downloader)
 
         self.download_box.connect("complete", self.download_complete)
@@ -32,3 +35,12 @@ class DownloadDialog(Gtk.Dialog):
         if response == Gtk.ResponseType.DELETE_EVENT:
             self.download_box.downloader.cancel()
             self.destroy()
+
+
+def simple_downloader(url, destination, callback, callback_args=None):
+    """Basic downloader with a DownloadDialog"""
+    if not callback_args:
+        callback_args = {}
+    dialog = DownloadDialog(url, destination)
+    dialog.run()
+    return callback(**callback_args)
