@@ -1,18 +1,14 @@
 """Commands for installer scripts"""
-# Standard Library
 import glob
 import json
 import multiprocessing
 import os
 import shlex
 import shutil
-import stat
 from gettext import gettext as _
 
-# Third Party Libraries
 from gi.repository import GLib
 
-# Lutris Modules
 from lutris import runtime
 from lutris.cache import get_cache_path
 from lutris.command import MonitoredCommand
@@ -34,10 +30,13 @@ class CommandsMixin:
 
     def _get_runner_version(self):
         """Return the version of the runner used for the installer"""
-        if self.runner in ("wine", "winesteam") and self.script.get(self.runner):
-            return self.script[self.runner].get("version")
-        if self.runner == "libretro":
-            return self.script["game"]["core"]
+        if (
+                self.installer.runner in ("wine", "winesteam")
+                and self.installer.script.get(self.installer.runner)
+        ):
+            return self.installer.script[self.installer.runner].get("version")
+        if self.installer.runner == "libretro":
+            return self.installer.script["game"]["core"]
         return None
 
     @staticmethod
@@ -74,8 +73,9 @@ class CommandsMixin:
     def chmodx(self, filename):
         """Make filename executable"""
         filename = self._substitute(filename)
-        file_stats = os.stat(filename)
-        os.chmod(filename, file_stats.st_mode | stat.S_IEXEC)
+        if not system.path_exists(filename):
+            raise ScriptingError("Invalid file '%s'. Can't make it executable" % filename)
+        system.make_executable(filename)
 
     def execute(self, data):
         """Run an executable file."""
@@ -124,13 +124,12 @@ class CommandsMixin:
         else:
             # Determine whether 'file' value is a file id or a path
             file_ref = self._get_file(file_ref)
-
+        if system.path_exists(file_ref) and not system.is_executable(file_ref):
+            logger.warning("Making %s executable", file_ref)
+            system.make_executable(file_ref)
         exec_path = system.find_executable(file_ref)
         if not exec_path:
             raise ScriptingError("Unable to find executable %s" % file_ref)
-        if not os.access(exec_path, os.X_OK):
-            logger.warning("Making %s executable", exec_path)
-            self.chmodx(exec_path)
 
         if terminal:
             terminal = system.get_default_terminal()
@@ -173,6 +172,7 @@ class CommandsMixin:
             extractor = data.get("format")
             logger.debug("extracting file %s to %s", filename, dest_path)
             self._killable_process(extract.extract_archive, filename, dest_path, merge_single, extractor)
+        logger.debug("Extract done")
 
     def input_menu(self, data):
         """Display an input request as a dropdown menu with options."""
@@ -215,7 +215,7 @@ class CommandsMixin:
               "containing the following file or folder:\n"
               "<i>%s</i>") % requires
         )
-        if self.runner == "wine":
+        if self.installer.runner == "wine":
             GLib.idle_add(self.parent.eject_button.show)
         GLib.idle_add(self.parent.ask_for_disc, message, self._find_matching_disc, requires)
         return "STOP"
@@ -250,6 +250,9 @@ class CommandsMixin:
         src, dst = self._get_move_paths(params)
         logger.debug("Merging %s into %s", src, dst)
         if not os.path.exists(src):
+            if params.get("optional"):
+                logger.info("Optional path %s not present", src)
+                return
             raise ScriptingError("Source does not exist: %s" % src, params)
         if not os.path.exists(dst):
             os.makedirs(dst)
@@ -274,6 +277,9 @@ class CommandsMixin:
         src, dst = self._get_move_paths(params)
         logger.debug("Moving %s to %s", src, dst)
         if not os.path.exists(src):
+            if params.get("optional"):
+                logger.info("Optional path %s not present", src)
+                return
             raise ScriptingError("I can't move %s, it does not exist" % src)
 
         if os.path.isfile(src):
@@ -354,7 +360,7 @@ class CommandsMixin:
             # than the one for this installer
             runner_name, task_name = task_name.split(".")
         else:
-            runner_name = self.runner
+            runner_name = self.installer.runner
         return runner_name, task_name
 
     def task(self, data):
@@ -375,10 +381,10 @@ class CommandsMixin:
             if wine_version:
                 data["wine_path"] = get_wine_version_exe(wine_version)
             data["prefix"] = data.get("prefix") \
-                or self.script.get("game", {}).get("prefix") \
+                or self.installer.script.get("game", {}).get("prefix") \
                 or "$GAMEDIR"
             data["arch"] = data.get("arch") \
-                or self.script.get("game", {}).get("arch") \
+                or self.installer.script.get("game", {}).get("arch") \
                 or WINE_DEFAULT_ARCH
             if task_name == "wineexec" and self.script_env:
                 data["env"] = self.script_env
@@ -463,7 +469,7 @@ class CommandsMixin:
 
     def write_config(self, params):
         """Write a key-value pair into an INI type config file."""
-        if params.get("data", None):
+        if params.get("data"):
             self._check_required_params(["file", "data"], params, "write_config")
         else:
             self._check_required_params(["file", "section", "key", "value"], params, "write_config")
@@ -483,7 +489,7 @@ class CommandsMixin:
             parser.read(config_file_path)
 
         data = {}
-        if params.get("data", None):
+        if params.get("data"):
             data = params["data"]
         else:
             data[params["section"]] = {}
@@ -512,4 +518,5 @@ class CommandsMixin:
         self.abort_current_task = process.terminate
         result = result_obj.get()  # Wait process end & reraise exceptions
         self.abort_current_task = None
+        logger.debug("Process %s returned: %s", func, result)
         return result
