@@ -1,20 +1,24 @@
+# Standard Library
 import os
+from gettext import gettext as _
+
+# Lutris Modules
 from lutris.runners.runner import Runner
 from lutris.util import system
 
 
 class jzintv(Runner):
-    human_name = "jzIntv"
-    description = "Intellivision Emulator"
-    platforms = ["Intellivision"]
+    human_name = _("jzIntv")
+    description = _("Intellivision Emulator")
+    platforms = [_("Intellivision")]
     runner_executable = "jzintv/bin/jzintv"
     game_options = [
         {
             "option": "main_file",
             "type": "file",
-            "label": "ROM file",
+            "label": _("ROM file"),
             "default_path": "game_path",
-            "help": (
+            "help": _(
                 "The game data, commonly called a ROM image. \n"
                 "Supported rom formats: .rom, .bin+.cfg, .int, .itv \n"
                 "The file extension must be lower-case."
@@ -25,21 +29,25 @@ class jzintv(Runner):
         {
             "option": "bios_path",
             "type": "directory_chooser",
-            "label": "Bios location",
-            "help": (
+            "label": _("Bios location"),
+            "help": _(
                 "Choose the folder containing the Intellivision bios "
                 "files (exec.bin and grom.bin).\n"
                 "These files contain code from the original hardware "
                 "necessary to the emulation."
             ),
         },
-        {"option": "fullscreen", "type": "bool", "label": "Fullscreen"},
+        {
+            "option": "fullscreen",
+            "type": "bool",
+            "label": _("Fullscreen")
+        },
         {
             "option": "resolution",
             "type": "choice",
             "label": "Resolution",
             "choices": (
-                ("320 x 200 (default)", "0"),
+                ("320 x 200", "0"),
                 ("640 x 480", "1"),
                 ("800 x 400", "5"),
                 ("800 x 600", "2"),
@@ -47,17 +55,21 @@ class jzintv(Runner):
                 ("1680 x 1050", "4"),
                 ("1600 x 1200", "6"),
             ),
+            "default": "0"
         },
     ]
 
     def play(self):
         """Run Intellivision game"""
         arguments = [self.get_executable()]
+
         selected_resolution = self.runner_config.get("resolution")
         if selected_resolution:
             arguments = arguments + ["-z%s" % selected_resolution]
+
         if self.runner_config.get("fullscreen"):
             arguments = arguments + ["-f"]
+
         bios_path = self.runner_config.get("bios_path", "")
         if system.path_exists(bios_path):
             arguments.append("--execimg=%s/exec.bin" % bios_path)
