@@ -1,53 +1,48 @@
 """Base module for runners"""
-# Standard Library
 import os
 from gettext import gettext as _
 
-# Third Party Libraries
 from gi.repository import Gtk
 
-# Lutris Modules
-from lutris import pga, runtime, settings
+from lutris import runtime, settings
 from lutris.command import MonitoredCommand
 from lutris.config import LutrisConfig
+from lutris.database.games import get_game_by_field
+from lutris.exceptions import UnavailableLibraries
 from lutris.gui import dialogs
 from lutris.runners import RunnerInstallationError
 from lutris.util import system
 from lutris.util.extract import ExtractFailure, extract_archive
 from lutris.util.http import Request
+from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import logger
 
 
-class RunnerMeta(type):
-    def __new__(mcs, name, bases, body):
-        if name != 'Runner' and 'play' not in body:
-            raise TypeError("The play method is not implemented in runner %s!" % name)
-        return super().__new__(mcs, name, bases, body)
-
-
-class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
+class Runner:  # pylint: disable=too-many-public-methods
 
     """Generic runner (base class for other runners)."""
 
     multiple_versions = False
     platforms = []
-    require_libs = []
     runnable_alone = False
     game_options = []
     runner_options = []
     system_options_override = []
     context_menu_entries = []
+    require_libs = []
     depends_on = None
     runner_executable = None
     entry_point_option = "main_file"
+    download_url = None
+    arch = None  # If the runner is only available for an architecture that isn't x86_64
 
     def __init__(self, config=None):
         """Initialize runner."""
-        self.arch = system.LINUX_SYSTEM.arch
         self.config = config
-        self.game_data = {}
         if config:
-            self.game_data = pga.get_game_by_field(self.config.game_config_id, "configpath")
+            self.game_data = get_game_by_field(self.config.game_config_id, "configpath")
+        else:
+            self.game_data = {}
 
     def __lt__(self, other):
         return self.name < other.name
@@ -60,7 +55,7 @@ class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
     @description.setter
     def description(self, value):
         """Leave the ability to override the docstring."""
-        self.__doc__ = value
+        self.__doc__ = value  # What the shit
 
     @property
     def name(self):
@@ -168,12 +163,43 @@ class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
         if os_env:
             env.update(os.environ.copy())
 
-        system_env = self.system_config.get("env") or {}
-        env.update(system_env)
+        # Override SDL2 controller configuration
+        sdl_gamecontrollerconfig = self.system_config.get("sdl_gamecontrollerconfig")
+        if sdl_gamecontrollerconfig:
+            path = os.path.expanduser(sdl_gamecontrollerconfig)
+            if system.path_exists(path):
+                with open(path, "r") as controllerdb_file:
+                    sdl_gamecontrollerconfig = controllerdb_file.read()
+            env["SDL_GAMECONTROLLERCONFIG"] = sdl_gamecontrollerconfig
 
+        # Set monitor to use for SDL 1 games
+        if self.system_config.get("sdl_video_fullscreen"):
+            env["SDL_VIDEO_FULLSCREEN_DISPLAY"] = self.system_config["sdl_video_fullscreen"]
+
+        # DRI Prime
         if self.system_config.get("dri_prime"):
             env["DRI_PRIME"] = "1"
 
+        # Prime vars
+        prime = self.system_config.get("prime")
+        if prime:
+            env["__NV_PRIME_RENDER_OFFLOAD"] = "1"
+            env["__GLX_VENDOR_LIBRARY_NAME"] = "nvidia"
+            env["__VK_LAYER_NV_optimus"] = "NVIDIA_only"
+
+        # Enable ACO compiler for AMD GPUs
+        if self.system_config.get("aco"):
+            env["RADV_PERFTEST"] = "aco"
+
+        # Set PulseAudio latency to 60ms
+        if self.system_config.get("pulse_latency"):
+            env["PULSE_LATENCY_MSEC"] = "60"
+
+        # Vulkan ICD files
+        vk_icd = self.system_config.get("vk_icd")
+        if vk_icd and vk_icd != "off" and system.path_exists(vk_icd):
+            env["VK_ICD_FILENAMES"] = vk_icd
+
         runtime_ld_library_path = None
 
         if self.use_runtime():
@@ -189,6 +215,9 @@ class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
                 ld_library_path = "$LD_LIBRARY_PATH"
             env["LD_LIBRARY_PATH"] = ":".join([runtime_ld_library_path, ld_library_path])
 
+        # Apply user overrides at the end
+        env.update(self.system_config.get("env") or {})
+
         return env
 
     def get_runtime_env(self):
@@ -205,6 +234,17 @@ class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
 
     def prelaunch(self):
         """Run actions before running the game, override this method in runners"""
+        available_libs = set()
+        for lib in set(self.require_libs):
+            if lib in LINUX_SYSTEM.shared_libraries:
+                if self.arch:
+                    if self.arch in [_lib.arch for _lib in LINUX_SYSTEM.shared_libraries[lib]]:
+                        available_libs.add(lib)
+                else:
+                    available_libs.add(lib)
+        unavailable_libs = set(self.require_libs) - available_libs
+        if unavailable_libs:
+            raise UnavailableLibraries(unavailable_libs, self.arch)
         return True
 
     def get_run_data(self):
@@ -259,7 +299,8 @@ class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
             from lutris.gui.dialogs import ErrorDialog
             try:
                 if hasattr(self, "get_version"):
-                    self.install(downloader=simple_downloader, version=self.get_version(use_default=False))
+                    version = self.get_version(use_default=False)  # pylint: disable=no-member
+                    self.install(downloader=simple_downloader, version=version)
                 else:
                     self.install(downloader=simple_downloader)
             except RunnerInstallationError as ex:
@@ -293,7 +334,7 @@ class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
             return
 
         versions = runner_info.get("versions") or []
-        arch = self.arch
+        arch = system.LINUX_SYSTEM.arch
         if version:
             if version.endswith("-i386") or version.endswith("-x86_64"):
                 version, arch = version.rsplit("-", 1)
@@ -325,12 +366,16 @@ class Runner(metaclass=RunnerMeta):  # pylint: disable=too-many-public-methods
             downloader,
             callback,
         )
+        opts = {"downloader": downloader, "callback": callback}
+        if self.download_url:
+            opts["dest"] = os.path.join(settings.RUNNER_DIR, self.name)
+            return self.download_and_extract(self.download_url, **opts)
         runner = self.get_runner_version(version)
         if not runner:
             raise RunnerInstallationError("Failed to retrieve {} ({}) information".format(self.name, version))
         if not downloader:
             raise RuntimeError("Missing mandatory downloader for runner %s" % self)
-        opts = {"downloader": downloader, "callback": callback}
+
         if "wine" in self.name:
             opts["merge_single"] = True
             opts["dest"] = os.path.join(
