@@ -4,12 +4,23 @@ import os
 import re
 import shutil
 import signal
+import stat
 import string
 import subprocess
 
+from gi.repository import GLib
+
+from lutris import settings
 from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import logger
 
+# Home folders that should never get deleted. This should be localized and return the
+# appropriate folders names for the current locale.
+PROTECTED_HOME_FOLDERS = (
+    "Documents", "Downloads", "Desktop",
+    "Pictures", "Videos", "Pictures", "Projects", "Games"
+)
+
 
 def execute(command, env=None, cwd=None, log_errors=False, quiet=False, shell=False, timeout=None):
     """
@@ -90,6 +101,16 @@ def get_file_checksum(filename, hash_type):
     return hasher.hexdigest()
 
 
+def is_executable(exec_path):
+    """Return whether exec_path is an executable"""
+    return os.access(exec_path, os.X_OK)
+
+
+def make_executable(exec_path):
+    file_stats = os.stat(exec_path)
+    os.chmod(exec_path, file_stats.st_mode | stat.S_IEXEC)
+
+
 def find_executable(exec_name):
     """Return the absolute path of an executable"""
     if not exec_name:
@@ -217,9 +238,9 @@ def create_folder(path):
     return path
 
 
-def is_removeable(path, excludes=None):
+def is_removeable(path):
     """Check if a folder is safe to remove (not system or home, ...)"""
-    if not path_exists(path) or path in excludes:
+    if not path_exists(path):
         return False
 
     parts = path.strip("/").split("/")
@@ -229,12 +250,9 @@ def is_removeable(path, excludes=None):
 
     if parts[0] == "home":
         if len(parts) <= 2:
-            # Path is a home folder
             return False
-        if parts[2] == ".wine":
-            # Protect main .wine folder
+        if len(parts) == 3 and parts[2] in PROTECTED_HOME_FOLDERS:
             return False
-
     return True
 
 
@@ -356,3 +374,24 @@ def get_existing_parent(path):
     if os.path.exists(path) and not os.path.isfile(path):
         return path
     return get_existing_parent(os.path.dirname(path))
+
+
+def update_desktop_icons():
+    """Update Icon for GTK+ desktop manager
+    Other desktop manager icon cache commands must be added here if needed
+    """
+    if find_executable("gtk-update-icon-cache"):
+        execute(["gtk-update-icon-cache", "-tf", os.path.join(GLib.get_user_data_dir(), "icons/hicolor")], quiet=True)
+        execute(["gtk-update-icon-cache", "-tf", os.path.join(settings.RUNTIME_DIR, "icons/hicolor")], quiet=True)
+
+
+def get_disk_size(path):
+    """Return the disk size in bytes of a folder"""
+    total_size = 0
+    for base, _dirs, files in os.walk(path):
+        total_size += sum([
+            os.stat(os.path.join(base, f)).st_size
+            for f in files
+            if os.path.isfile(os.path.join(base, f))
+        ])
+    return total_size
